@@ -1375,7 +1375,7 @@ class Insight_Definition:
 
         if card_slug is not None:
             try:
-                url = self.smart_insight_url + "/definitions/agent/" + self.agent_id + "/slug/" + card_slug
+                url = self.smart_insight_url + "/definitions/insight-slugs/" + card_slug + "?agentId=" + self._agentId + "&definitionOnly=true"
 
                 r = self.__make_get_request(url)
 
